diff --git a/osu.Game/Skinning/Components/BeatmapAttributeText.cs b/osu.Game/Skinning/Components/BeatmapAttributeText.cs
index 06f0d9cea9..6e1d655cef 100644
--- a/osu.Game/Skinning/Components/BeatmapAttributeText.cs
+++ b/osu.Game/Skinning/Components/BeatmapAttributeText.cs
@@ -124,7 +124,7 @@ private void updateLabel()
protected override void SetFont(FontUsage font) => text.Font = font.With(size: 40);
- protected override void SetFontColour(Colour4 fontColour) => text.Colour = fontColour;
+ protected override void SetTextColour(Colour4 textColour) => text.Colour = textColour;
}
// WARNING: DO NOT ADD ANY VALUES TO THIS ENUM ANYWHERE ELSE THAN AT THE END.
diff --git a/osu.Game/Skinning/Components/PlayerName.cs b/osu.Game/Skinning/Components/PlayerName.cs
index 70672a1f58..5b6ded0cc5 100644
--- a/osu.Game/Skinning/Components/PlayerName.cs
+++ b/osu.Game/Skinning/Components/PlayerName.cs
@@ -54,6 +54,6 @@ private void load()
protected override void SetFont(FontUsage font) => text.Font = font.With(size: 40);
- protected override void SetFontColour(Colour4 fontColour) => text.Colour = fontColour;
+ protected override void SetTextColour(Colour4 textColour) => text.Colour = textColour;
}
}
diff --git a/osu.Game/Skinning/Components/TextElement.cs b/osu.Game/Skinning/Components/TextElement.cs
index 9d66c58ae8..6e875c5590 100644
--- a/osu.Game/Skinning/Components/TextElement.cs
+++ b/osu.Game/Skinning/Components/TextElement.cs
@@ -37,6 +37,6 @@ public TextElement()
protected override void SetFont(FontUsage font) => text.Font = font.With(size: 40);
- protected override void SetFontColour(Colour4 fontColour) => text.Colour = fontColour;
+ protected override void SetTextColour(Colour4 textColour) => text.Colour = textColour;
}
}
diff --git a/osu.Game/Skinning/FontAdjustableSkinComponent.cs b/osu.Game/Skinning/FontAdjustableSkinComponent.cs
index e3052aee5c..0821edf7fc 100644
--- a/osu.Game/Skinning/FontAdjustableSkinComponent.cs
+++ b/osu.Game/Skinning/FontAdjustableSkinComponent.cs
@@ -21,15 +21,15 @@ public abstract partial class FontAdjustableSkinComponent : Container, ISerialis
[SettingSource(typeof(SkinnableComponentStrings), nameof(SkinnableComponentStrings.Font), nameof(SkinnableComponentStrings.FontDescription))]
public Bindable Font { get; } = new Bindable(Typeface.Torus);
- [SettingSource(typeof(SkinnableComponentStrings), nameof(SkinnableComponentStrings.FontColour), nameof(SkinnableComponentStrings.FontColourDescription))]
- public BindableColour4 FontColour { get; } = new BindableColour4(Colour4.White);
+ [SettingSource(typeof(SkinnableComponentStrings), nameof(SkinnableComponentStrings.TextColour), nameof(SkinnableComponentStrings.TextColourDescription))]
+ public BindableColour4 TextColour { get; } = new BindableColour4(Colour4.White);
///
/// Implement to apply the user font selection to one or more components.
///
protected abstract void SetFont(FontUsage font);
- protected abstract void SetFontColour(Colour4 fontColour);
+ protected abstract void SetTextColour(Colour4 textColour);
protected override void LoadComplete()
{
@@ -44,7 +44,7 @@ protected override void LoadComplete()
SetFont(f);
}, true);
- FontColour.BindValueChanged(e => SetFontColour(e.NewValue), true);
+ TextColour.BindValueChanged(e => SetTextColour(e.NewValue), true);
}
}
}
diff --git a/osu.Game/Localisation/SkinComponents/SkinnableComponentStrings.cs b/osu.Game/Localisation/SkinComponents/SkinnableComponentStrings.cs
index bd22527f67..33fda23cb0 100644
--- a/osu.Game/Localisation/SkinComponents/SkinnableComponentStrings.cs
+++ b/osu.Game/Localisation/SkinComponents/SkinnableComponentStrings.cs
@@ -70,14 +70,14 @@ public static class SkinnableComponentStrings
public static LocalisableString ColourDescription => new TranslatableString(getKey(@"colour_description"), @"The colour of the component.");
///
- /// "Font colour"
+ /// "Text colour"
///
- public static LocalisableString FontColour => new TranslatableString(getKey(@"font_colour"), @"Font colour");
+ public static LocalisableString TextColour => new TranslatableString(getKey(@"text_colour"), @"Text colour");
///
/// "The colour of the font."
///
- public static LocalisableString FontColourDescription => new TranslatableString(getKey(@"font_colour_description"), @"The colour of the font.");
+ public static LocalisableString TextColourDescription => new TranslatableString(getKey(@"text_colour_description"), @"The colour of the text.");
private static string getKey(string key) => $@"{prefix}:{key}";
}
@@ -70,14 +70,14 @@ public static class SkinnableComponentStrings
///
- /// "The colour of the font."
+ /// "The colour of the text."
///